import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)

import mns_common.component.trade.trade_service_api as trade_service_api


## 自动一键打新
def auto_ipo_buy():
    trade_service_api.auto_ipo_buy()


if __name__ == '__main__':
    auto_ipo_buy()



import os
import sys

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)

import mns_scheduler.risk.major_violations.register_and_investigate_stock_sync_api \
    as register_and_investigate_stock_sync_api
from loguru import logger
from apscheduler.schedulers.blocking import BlockingScheduler
from datetime import datetime
import mns_scheduler.dt.stock_dt_pool_sync as stock_dt_pool_sync_api
import mns_scheduler.zb.stock_zb_pool_sync as stock_zb_pool_sync_api
import mns_common.component.trade_date.trade_date_common_service_api as trade_date_common_service_api
import mns_common.utils.date_handle_util as date_handle_util
import mns_scheduler.k_line.sync.daily_week_month_line_sync as daily_week_month_line_sync_api
import mns_common.utils.ip_util as ip_util
import mns_scheduler.db.col_move_service as col_move_service
import mns_scheduler.db.db_status as db_status_api
import mns_scheduler.big_deal.ths_big_deal_sync as ths_big_deal_sync_api
import mns_scheduler.zt.open_data.kcx_high_chg_open_data_sync as kcx_high_chg_open_data_sync
import mns_scheduler.zt.export.export_kcx_high_chg_open_data_to_excel as export_kcx_high_chg_open_data_to_excel
import mns_scheduler.zt.connected_boards.zt_five_boards_sync_api as zt_five_boards_sync_api
import mns_scheduler.zt.zt_pool.zt_pool_sync_api as zt_pool_sync_api
import mns_scheduler.k_line.clean.k_line_info_clean_task as k_line_info_clean_service
import mns_scheduler.concept.clean.ths_concept_clean_api as ths_concept_choose_api
import mns_common.api.em.east_money_stock_gdfx_free_top_10_api as east_money_stock_gdfx_free_top_10_api
import \
    mns_scheduler.concept.ths.update_concept_info.sync_one_concept_all_symbols_api as sync_one_concept_all_symbols_api
import \
    mns_scheduler.concept.ths.update_concept_info.sync_one_symbol_all_concepts_api as sync_one_symbol_all_concepts_api
import mns_scheduler.kpl.selection.total.sync_kpl_best_total_sync_api as sync_kpl_best_total_sync_api
import mns_scheduler.company_info.company_info_sync_api as company_info_sync_api
import mns_scheduler.trade.auto_ipo_buy_api as auto_ipo_buy_api
import mns_scheduler.kpl.selection.index.sync_best_choose_his_index as sync_best_choose_his_index
import mns_scheduler.concept.ths.common.ths_concept_update_common_api as ths_concept_update_common_api
import mns_scheduler.trade.sync_position_api as sync_position_api
import mns_scheduler.concept.clean.kpl_concept_clean_api as kpl_concept_clean_api
import mns_scheduler.company_info.de_list_stock_service as de_list_stock_service
import mns_scheduler.irm.stock_irm_cninfo_service as stock_irm_cninfo_service
import mns_scheduler.open.sync_one_day_open_data_to_db_service as sync_one_day_open_data_to_db_service
import mns_scheduler.zt.high_chg.sync_high_chg_pool_service as sync_high_chg_pool_service
import mns_scheduler.zt.high_chg.sync_high_chg_real_time_quotes_service as sync_high_chg_real_time_quotes_service
import mns_scheduler.risk.self.wei_pan_stock_api as wei_pan_stock_api
import mns_scheduler.risk.transactions.transactions_check_api as transactions_check_api
import mns_scheduler.concept.ths.sync_new_index.sync_ths_concept_new_index_api as sync_ths_concept_new_index_api


# 同步交易日期任务完成
def sync_trade_date():
    trade_date_common_service_api.sync_trade_date()
    logger.info('同步交易日期任务完成')


# 跌停信息
def sync_stock_dt_pool():
    now_date = datetime.now()
    str_now_day = now_date.strftime('%Y-%m-%d')
    if trade_date_common_service_api.is_trade_day(str_now_day):
        stock_dt_pool_sync_api.sync_stock_dt_pool(str_now_day)
        logger.info("同步跌停信息任务执行成功:{}", str_now_day)


# 炸板信息
def sync_stock_zb_pool():
    now_date = datetime.now()
    str_now_day = now_date.strftime('%Y-%m-%d')
    if trade_date_common_service_api.is_trade_day(str_now_day):
        stock_zb_pool_sync_api.sync_stock_zb_pool(str_now_day)
        logger.info("同步跌停信息任务执行成功:{}", str_now_day)


# 定时同步每周交易行情数据(前复权)
def stock_sync_qfq_weekly():
    now_date = datetime.now()
    str_now_date = now_date.strftime('%Y-%m-%d')
    if date_handle_util.last_day_of_week(now_date):
        logger.info('同步每周行情数据(前复权):' + str_now_date)
        daily_week_month_line_sync_api.sync_all_daily_data('weekly', 'qfq', 'stock_qfq_weekly', None)


# # 定时同步每周交易行情数据(前复权)
def stock_sync_qfq_monthly():
    now_date = datetime.now()
    str_now_date = now_date.strftime('%Y-%m-%d')
    if date_handle_util.last_day_month(now_date):
        logger.info('同步每周行情数据(前复权):' + str_now_date)
        daily_week_month_line_sync_api.sync_all_daily_data('monthly', 'qfq', 'stock_qfq_monthly',
                                                           None)


#  当天实时数据备份
def col_data_move():
    now_date = datetime.now()
    str_day = now_date.strftime('%Y-%m-%d')
    logger.info('当天实时数据备份:{}', str_day)
    if trade_date_common_service_api.is_trade_day(str_day):
        mac_address = ip_util.get_mac_address()
        if mac_address is not None and mac_address == ip_util.WINDOWS_MAC_ADDRESS_CD:
            col_move_service.sync_col_move(str_day)
        else:
            # 删除最早一天数据
            col_move_service.delete_exist_data(str_day)


# db 状态check
def db_status_check():
    db_status_api.db_status_check()


# 同步大单数据
def sync_ths_big_deal():
    now_date = datetime.now()
    str_now_day = now_date.strftime('%Y-%m-%d')
    if trade_date_common_service_api.is_trade_day(str_now_day):
        logger.info('更新大单数据')
        ths_big_deal_sync_api.sync_ths_big_deal(False)


# 定时同步每日交易行情数据(前复权)
def stock_daily_sync_qfq():
    now_date = datetime.now()
    str_now_date = now_date.strftime('%Y-%m-%d')
    logger.info('同步每日行情数据(前复权):' + str_now_date)
    daily_week_month_line_sync_api.sync_all_daily_data('daily',
                                                       'qfq', 'stock_qfq_daily', None)


# 同步当日k c x 高涨幅数据
def realtime_quotes_now_zt_kc_data_sync():
    now_date = datetime.now()
    str_day = now_date.strftime('%Y-%m-%d')
    if trade_date_common_service_api.is_trade_day(str_day):
        # 同步当日kcx 高涨幅 当天交易数据和开盘数据
        kcx_high_chg_open_data_sync.sync_all_kc_zt_data(str_day, None)
        # 同步当日开盘数据
        sync_one_day_open_data_to_db_service.sync_one_day_open_data(str_day)
        # 涨停数据同步到excel
        export_kcx_high_chg_open_data_to_excel.export_kc_zt_data(str_day)


# 同步涨停池
def sync_stock_zt_pool():
    now_date = datetime.now()
    str_day = now_date.strftime('%Y-%m-%d')
    if trade_date_common_service_api.is_trade_day(str_day):
        logger.info('同步当天涨停池股开始')
        stock_zt_pool = zt_pool_sync_api.save_zt_info(str_day)
        zt_five_boards_sync_api.update_five_connected_boards_task(stock_zt_pool)
        logger.info('同步当天涨停池股票完成')


# 保存今天高涨幅数据
def sync_toady_stock_zt_pool():
    logger.info('同步今天涨幅大于9.5的symbol')
    now_date = datetime.now()
    str_day = now_date.strftime('%Y-%m-%d')
    # 同步高涨幅实时行情
    sync_high_chg_real_time_quotes_service.sync_high_chg_real_time_quotes(str_day)
    # 同步高涨幅列表
    sync_high_chg_pool_service.sync_stock_high_chg_pool_list(str_day, None)


# 计算下一个交易日k线数据
def generate_new_day_k_line_info():
    now_date = datetime.now()
    str_day = now_date.strftime('%Y-%m-%d')
    # 生成下一个交易日日期k线数据 number=2 获取下一个交易日 日期
    next_trade_day = trade_date_common_service_api.get_further_trade_date(str_day, 2)
    k_line_info_clean_service.sync_k_line_info_task(next_trade_day)
    logger.info('计算当日k线信息完成:{}', str_day)


# 同步一天k线 涨停 数据
def sync_daily_data_info():
    # 同步k线数据
    try:
        stock_daily_sync_qfq()
    except BaseException as e:
        logger.error("同步当日k线数据异常:{}", e)

    # 同步当日k c x 高涨幅数据
    try:
        realtime_quotes_now_zt_kc_data_sync()
    except BaseException as e:
        logger.error("同步当日kcx高涨幅数据异常:{}", e)

    # 同步涨停池数据信息
    try:
        sync_stock_zt_pool()
    except BaseException as e:
        logger.error("同步涨停数据信息异常:{}", e)

    # 同步今日高涨幅数据 依赖涨停股票池的数据
    try:
        sync_toady_stock_zt_pool()
    except BaseException as e:
        logger.error("同步今日高涨幅数据异常:{}", e)

    # 计算当日k线数据
    try:
        generate_new_day_k_line_info()
    except BaseException as e:
        logger.error("计算当日k线数据异常:{}", e)


# 同步当天交易k线数据
def sync_today_trade_k_line_info():
    now_date = datetime.now()
    str_day = now_date.strftime('%Y-%m-%d')
    if trade_date_common_service_api.is_trade_day(str_day):
        k_line_info_clean_service.sync_k_line_info_task(str_day)
        logger.info('计算当日k线信息完成:{}', str_day)


# 同步所有股票前十大流通股本
def sync_stock_gdfx_free_top_10_one_day():
    logger.info('同步所有股票前十大流通股本')
    now_date = datetime.now()
    str_day = now_date.strftime('%Y-%m-%d')
    east_money_stock_gdfx_free_top_10_api.sync_stock_gdfx_free_top_10_one_day(str_day)


# 更新概念信息
def concept_info_clean():
    #  更新空概念名称
    ths_concept_choose_api.update_null_name()
    #  更新概念包含个数
    ths_concept_choose_api.update_ths_concept_info()
    # 开盘啦概念信息更新
    kpl_concept_clean_api.update_kpl_concept_info()


# 同步概念下所有股票组成 by 概念指数
def update_one_concept_all_symbol_detail():
    logger.info('同步概念下所有股票组成')
    sync_one_concept_all_symbols_api.update_concept_all_symbol_detail()
    ths_concept_update_common_api.update_ths_concept_choose_null_reason()


# 同步单只股票下所有概念 by 股票代码
def update_one_symbol_all_concepts():
    logger.info('同步单只股票所有概念组成')
    sync_one_symbol_all_concepts_api.sync_symbol_all_concept(None)
    ths_concept_update_common_api.update_ths_concept_choose_null_reason()


# 同步开盘啦精选指数
def sync_all_kpl_plate_info():
    logger.info('同步开盘啦精选指数开始')
    sync_kpl_best_total_sync_api.sync_all_plate_info()


# 更新一二级关系
def update_best_choose_plate_relation():
    logger.info('同步开盘啦精选指数关系')
    sync_kpl_best_total_sync_api.update_best_choose_plate_relation()


# 同步ths新概念
def sync_new_concept_index():
    sync_ths_concept_new_index_api.sync_ths_concept_new_index()
    logger.info("同步ths新概念任务完成")

    ths_concept_update_common_api.update_ths_concept_choose_null_reason()
    logger.info("更新空的入选概念任务完成")


# 同步ths新概念 轮训任务
def sync_new_concept_index_task():
    now_date = datetime.now()
    hour = now_date.hour
    if hour != 9:
        sync_ths_concept_new_index_api.sync_ths_concept_new_index()
        logger.info("同步ths新概念任务完成")


# 清洗公司基本信息
def update_company_base_info():
    company_info_sync_api.sync_company_base_info(None)
    company_info_sync_api.fix_company_industry(None)
    # 退市股票同步
    de_list_stock_service.sync_de_list_stock()
    logger.info('同步公司基本信息任务完成')


# 自动打新
def auto_ipo_buy():
    now_date = datetime.now()
    str_day = now_date.strftime('%Y-%m-%d')
    if trade_date_common_service_api.is_trade_day(str_day):
        auto_ipo_buy_api.auto_ipo_buy()


# 同步持仓
def sync_position():
    now_date = datetime.now()
    str_day = now_date.strftime('%Y-%m-%d')
    # 同步持仓
    if trade_date_common_service_api.is_trade_day(str_day):
        logger.info('同步持仓任务完成')
        sync_position_api.sync_position()


# 同步开盘啦当日精选指数行情数据

def sync_kpl_best_his_quotes():
    now_date = datetime.now()
    str_day = now_date.strftime('%Y-%m-%d')
    last_trade_day = trade_date_common_service_api.get_last_trade_day(str_day)
    if trade_date_common_service_api.is_trade_day(last_trade_day):
        sync_best_choose_his_index.sync_best_choose_his_index(last_trade_day)
        logger.info('同步开盘啦当日精选指数行情数据任务完成')


# 同步高风险的股票
def sync_high_risk_stocks():
    logger.info('同步被立案调查的股票')
    register_and_investigate_stock_sync_api.sync_register_and_investigate_stocks()
    reason_detail = '微盘股拉黑'
    concept_code_wei_pan = '883418'
    wei_pan_stock_api.add_concept_to_lack_list(concept_code_wei_pan, reason_detail)
    logger.info('同步交易类风险的股票')
    transactions_check_api.transactions_check_task()


# 同步互动回答
def sync_all_interactive_questions():
    now_date = datetime.now()
    str_day = now_date.strftime('%Y-%m-%d')
    hour = now_date.hour
    tag = (bool(1 - trade_date_common_service_api.is_trade_day(str_day))) or (hour >= 17)
    if tag:
        logger.info('同步互动回答')
        stock_irm_cninfo_service.sync_all_interactive_questions(None)


# # 定义BlockingScheduler
blockingScheduler = BlockingScheduler()
# sync_trade_date 同步交易日期
blockingScheduler.add_job(sync_trade_date, 'cron', hour='20', minute='43')

# 跌停信息同步
blockingScheduler.add_job(sync_stock_dt_pool, 'cron', hour='15,17,21,03,07', minute='37')

# 炸板信息同步
blockingScheduler.add_job(sync_stock_zb_pool, 'cron', hour='15,17,21,03,07', minute='55')

# (前复权--周k线)
blockingScheduler.add_job(stock_sync_qfq_weekly, 'cron', day_of_week='fri', hour=16, minute=20)

# (前复权--月k线)
blockingScheduler.add_job(stock_sync_qfq_monthly, 'cron', hour='15,18', minute='35')

# 数据备份
blockingScheduler.add_job(col_data_move, 'cron', hour='15', minute='33')

# 数据库健康检查
blockingScheduler.add_job(db_status_check, 'interval', seconds=30, max_instances=4)

# 同步大单数据 暂停同步 20240430
# blockingScheduler.add_job(sync_ths_big_deal, 'cron', hour='09', minute='30', max_instances=4)

# todo 需要前后顺序执行
# todo 当日k线信息
# 同步一天k线 涨停 数据
blockingScheduler.add_job(sync_daily_data_info, 'cron', hour='15,20', minute='26')

# 开盘前同步当天交易需要的k线数据
blockingScheduler.add_job(sync_today_trade_k_line_info, 'cron', hour='08', minute='30')

# 同步十大流通股东信息
blockingScheduler.add_job(sync_stock_gdfx_free_top_10_one_day, 'cron', hour='08,22', minute='23')

# 更新同花顺概念信息
blockingScheduler.add_job(concept_info_clean, 'cron', hour='9,12,20', minute='24')

# 更新概念指数下所有股票组成 by 概念代码
blockingScheduler.add_job(update_one_concept_all_symbol_detail, 'cron', hour='08,18,12', minute='30')

# 同步单只股票下所有概念 by 股票代码
blockingScheduler.add_job(update_one_symbol_all_concepts, 'cron', hour='09,18,12', minute='15')

# 开盘前同步同花顺新概念指数
blockingScheduler.add_job(sync_new_concept_index, 'cron', hour='09,22', minute='01,10,20,28,41,58')

# 同步同花顺新增概念指数(定时轮训,暂时10分钟)
blockingScheduler.add_job(sync_new_concept_index_task, 'interval', minutes=10, max_instances=4)

# 同步开盘啦新增精选概念(定时轮训,暂时五分钟)
blockingScheduler.add_job(sync_all_kpl_plate_info, 'interval', minutes=5, max_instances=4)

# 同步公司基本信息
blockingScheduler.add_job(update_company_base_info, 'cron', hour='08,19', minute='05')
# 更新当天涨停股票池
blockingScheduler.add_job(sync_stock_zt_pool, 'cron', hour='15,19,21,23', minute='42')

# 自动打新 打新中签高时间段 10:30-11:30
blockingScheduler.add_job(auto_ipo_buy, 'cron', hour='10', minute='40,50')

# 更新开盘啦指数关系
blockingScheduler.add_job(update_best_choose_plate_relation, 'cron', hour='09,18', minute='25')

# 更新开盘啦指数关系
blockingScheduler.add_job(sync_kpl_best_his_quotes, 'cron', hour='18,22', minute='25')

# 更新开盘啦指数关系
blockingScheduler.add_job(sync_position, 'cron', hour='0,08', minute='10')

# 同步高风险股票
blockingScheduler.add_job(sync_high_risk_stocks, 'cron', hour='0,09,12,16', minute='20')

# 同步互动回答
blockingScheduler.add_job(sync_all_interactive_questions, 'cron', hour='08,12,17', minute='05')

print('定时任务启动成功')
blockingScheduler.start()
#
# if __name__ == '__main__':
#     col_data_move()



import os
import sys

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)

import mns_common.utils.data_frame_util as data_frame_util
import mns_common.constant.db_name_constant as db_name_constant
import datetime
import mns_common.component.cache.cache_service as cache_service
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.component.trade.trade_service_api as trade_service_api
from loguru import logger
from mns_common.utils.async_fun import async_fun

mongodb_util = MongodbUtil('27017')

AUTO_SELL_KEY = "AUTO_SELL_KEY"

# 当前跌幅卖出阈值
AUTO_SELL_CHG = -8
# 收益率阈值
AUTO_SELL_PROFIT_LOSS_CHG = -11.0


# 自动卖出
@async_fun
def auto_sell_stock(realtime_quotes_now):
    sell_flag = cache_service.get_cache(AUTO_SELL_KEY)
    if sell_flag is not None and bool(1 - sell_flag):
        return
    now_date = datetime.datetime.now()
    str_day = now_date.strftime('%Y-%m-%d')
    query_exist = {'str_day': str_day, "valid": True}
    position_stock_df = mongodb_util.find_query_data(db_name_constant.POSITION_STOCK, query_exist)
    if data_frame_util.is_empty(position_stock_df):
        cache_service.set_cache(AUTO_SELL_KEY, False)
        return None
    else:
        cache_service.set_cache(AUTO_SELL_KEY, True)
        position_stock_symbol_list = list(position_stock_df['symbol'])
        realtime_quotes_now_position = realtime_quotes_now.loc[
            realtime_quotes_now['symbol'].isin(position_stock_symbol_list)]
        sell_stock_detail(realtime_quotes_now_position, position_stock_df, str_day, now_date)


def sell_stock_detail(realtime_quotes_now_position, position_stock_df, str_day, now_date):
    for stock_one in realtime_quotes_now_position.itertuples():
        try:

            symbol = stock_one.symbol
            sell_price = trade_service_api.get_last_sell_price(symbol)
            position_stock_df_one = position_stock_df.loc[position_stock_df['symbol'] == symbol]
            available_position = list(position_stock_df_one['available_position'])[0]
            if sell_signal(stock_one, now_date, position_stock_df_one):
                sell_result = trade_service_api.order_sell(symbol, sell_price, available_position)
                if "message" in sell_result:
                    result_msg = sell_result['message']
                    if result_msg == 'success':
                        update_position_status(symbol, None, str_day)
                elif "entrust_no" in sell_result:
                    sell_entrust_no = sell_result['entrust_no']
                    if sell_entrust_no is not None:
                        update_position_status(symbol, sell_entrust_no, str_day)

        except BaseException as e:
            logger.error("自动卖出异常:{},{}", stock_one.symbol, e)


# 卖出信号 TODO 待优化
def sell_signal(stock_one, now_date, position_stock_df_one):
    chg = stock_one.chg
    wei_bi = stock_one.wei_bi

    hour = now_date.hour
    minute = now_date.minute
    # 跌停直接卖出
    if wei_bi == -100:
        return True
    # 开盘五分钟先看看
    if hour == 9 and minute <= 35:
        return False
    # 尾盘卖不出了
    if hour == 14 and minute >= 57:
        return False

    # 自动卖出涨幅
    if chg < AUTO_SELL_CHG:
        return True

    cost_price = list(position_stock_df_one['cost_price'])[0]
    now_price = stock_one.now_price
    # 收益率
    profit_loss_chg = round((now_price - cost_price) * 100 / cost_price, 2)
    # 收益卖出阈值
    if profit_loss_chg < AUTO_SELL_PROFIT_LOSS_CHG:
        return True
    return False


# 更新持仓状态
def update_position_status(symbol, sell_entrust_no, str_day):
    update_query = {'symbol': symbol, 'str_day': str_day}
    new_values = {"$set": {"valid": False, "sell_entrust_no": sell_entrust_no}}
    mongodb_util.update_many(update_query, new_values, db_name_constant.POSITION_STOCK)


import mns_common.api.em.east_money_stock_api as east_money_stock_api

if __name__ == '__main__':
    sell_price_01 = trade_service_api.get_last_sell_price('002336')
    while True:
        real_time_quotes_now = east_money_stock_api.get_real_time_quotes_all_stocks()
        auto_sell_stock(real_time_quotes_now)



import os
import sys

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)

import mns_common.utils.date_handle_util as date_handle_util
import os
from loguru import logger
from mns_common.db.MongodbUtil import MongodbUtil

mongodb_util = MongodbUtil('27017')
mongodb_util_21019 = MongodbUtil('27019')


def create_db_index(str_day):
    try:
        mongodb_util_21019.create_index('realtime_quotes_now_' + str_day, [("symbol", 1)])
        mongodb_util_21019.create_index('realtime_quotes_now_' + str_day, [("number", 1)])
        mongodb_util_21019.create_index('realtime_quotes_now_' + str_day, [("symbol", 1), ("number", 1)])
        mongodb_util_21019.create_index('realtime_quotes_now_' + str_day, [("str_now_date", 1)])
        logger.info("创建索引成功:{}", str_day)
    except BaseException as e:
        logger.warning("创建索引异常:{}", e)


# mongodump --host 127.0.0.1:27018  -d patience    -o H:\back
def get_mongodb_util(str_day):
    sync_date = date_handle_util.add_date_day(date_handle_util.no_slash_date(str_day), 0)
    month = sync_date.month
    day = sync_date.day
    if month < 8:
        return '127.0.0.1:27018'
    elif month == 8 and day < 15:
        return '127.0.0.1:27018'
    else:
        return '127.0.0.1:27017'


def db_export(db, str_day):
    col = 'realtime_quotes_now_' + str_day
    cmd = 'F:/mongo/bin/mongodump.exe --host ' + db + ' -d patience -c ' + col + ' -o D:/back'
    os.system(cmd)
    logger.info("export finished:{}", str_day)


def db_import(db, str_day):
    col = 'realtime_quotes_now_' + str_day
    create_db_index(str_day)
    cmd = 'F:/mongo/bin/mongorestore.exe --host ' + db + ' -d patience -c ' + col + ' D:/back/patience/' + col + '.bson'
    os.system(cmd)

    path = 'D:\\back\\patience\\realtime_quotes_now_' + str_day + '.bson'
    cmd_del = 'del /F /S /Q ' + path
    os.system(cmd_del)

    logger.info("import finished:{}", str_day)


def trans_one_day_trade_data(str_day, db1, db2):
    db_export(db1, str_day)
    db_import(db2, str_day)


def sync_col_move(str_day):
    query_trade_day = {"trade_date": str_day}
    if mongodb_util.exist_data_query('trade_date_list', query_trade_day):
        try:
            db_export('127.0.0.1:27017', str_day)
            db_import('127.0.0.1:27019', str_day)
            delete_exist_data(str_day)
        except BaseException as e:
            logger.error("备份数据出现错误:{}", e)


def delete_exist_data(str_day):
    query_trade_day = {"trade_date": str_day}
    if mongodb_util.exist_data_query('trade_date_list', query_trade_day):
        # 删除27017中最早一天的实时数据
        query = {"tag": False}
        trade_date_one = mongodb_util.ascend_query(query, 'trade_date_list', 'trade_date', 1)
        trade_date = list(trade_date_one['trade_date'])[0]
        db_name = 'realtime_quotes_now_' + trade_date
        mongodb_util.drop_collection(db_name)

        query_date = {'trade_date': trade_date}
        new_values = {"$set": {"tag": True}}
        mongodb_util.update_many(query_date, new_values, 'trade_date_list')

        return trade_date_one


def db_export_col(db, col):
    cmd = 'D:/MongoDB/tools/bin/mongodump.exe --host ' + db + ' -d patience -c ' + col + ' -o G:/backup'
    os.system(cmd)

    logger.info("export finished:{}", col)


# D:\software\mongodb-tools\mongodb-database-tools-windows-x86_64-100.5.2\bin
def db_import_col(db, col):
    cmd = 'D:/software/mongodb-tools/mongodb-database-tools-windows-x86_64-100.5.2/bin/mongorestore.exe --host ' + db + ' -d patience -c ' + col + ' D:/back/patience/' + col + '.bson'
    os.system(cmd)

    logger.info("import finished:{}", col)


# -u "username" -p "password"
if __name__ == '__main__':
    # sync_col_move('2024-05-28')
    # sync_col_move('2024-05-30')
    # sync_col_move('2024-05-31')
    sync_col_move('2024-06-11')
    sync_col_move('2024-06-12')



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)

import mns_common.component.common_service_fun_api as common_service_fun_api
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.constant.db_name_constant as db_name_constant
import mns_common.api.em.east_money_stock_api as east_money_stock_api
import mns_common.utils.data_frame_util as data_frame_util
mongodb_util = MongodbUtil('27017')


def get_sec_code(symbol):
    classification = common_service_fun_api.classify_symbol_one(symbol)
    if classification in ['K', 'H']:
        return 'SH' + symbol
    elif classification in ['C', 'S']:
        return 'SZ' + symbol
    else:
        return 'BJ' + symbol


# 查询利润表数据
def find_profit_report(period_time):
    query = {"REPORT_DATE": period_time}
    return mongodb_util.find_query_data(db_name_constant.EM_STOCK_PROFIT, query)


# 查询资产表
def find_asset_liability_report(period_time):
    query = {"REPORT_DATE": period_time}
    return mongodb_util.find_query_data(db_name_constant.EM_STOCK_ASSET_LIABILITY, query)



# 查出未报告的股票
def find_un_report_symbol(period_time, report_name):
    real_time_quotes_df = east_money_stock_api.get_real_time_quotes_all_stocks()
    real_time_quotes_df = real_time_quotes_df.loc[~(real_time_quotes_df['name'].str.contains('退'))]
    real_time_quotes_df.dropna(subset=['list_date'], axis=0, inplace=True)

    de_list_stock_df = mongodb_util.find_all_data(db_name_constant.DE_LIST_STOCK)
    real_time_quotes_df = real_time_quotes_df.loc[
        ~(real_time_quotes_df['symbol'].isin(list(de_list_stock_df['symbol'])))]

    if report_name == db_name_constant.EM_STOCK_ASSET_LIABILITY:
        had_asset_df = find_asset_liability_report(period_time)
        if data_frame_util.is_not_empty(had_asset_df):
            real_time_quotes_df = real_time_quotes_df.loc[
                ~(real_time_quotes_df['symbol'].isin(list(had_asset_df['SECURITY_CODE'])))]
    if report_name == db_name_constant.EM_STOCK_PROFIT:
        had_profit_df = find_profit_report(period_time)
        if data_frame_util.is_not_empty(had_profit_df):
            real_time_quotes_df = real_time_quotes_df.loc[
                ~(real_time_quotes_df['symbol'].isin(list(had_profit_df['SECURITY_CODE'])))]
    return real_time_quotes_df



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)

import datetime
import mns_common.utils.date_handle_util as date_util
import mns_common.component.company.company_common_service_api as company_common_service_api
from loguru import logger
import mns_common.api.em.east_money_stock_api as east_money_stock_api
import time
import mns_common.component.common_service_fun_api as common_service_fun_api
import mns_common.component.data.data_init_api as data_init_api
import mns_scheduler.real_time.realtime_quotes_now_create_db_index as realtime_quotes_now_create_db_index_api
import pandas as pd
from mns_common.db.MongodbUtil import MongodbUtil
from mns_common.utils.async_fun import async_fun
import mns_scheduler.trade.auto_sell_service_api as auto_sell_service_api
import mns_common.constant.db_name_constant as db_name_constant
import warnings

warnings.filterwarnings("ignore")

mongodb_util = MongodbUtil('27017')
order = ["_id",
         "symbol",
         "name",
         "industry",
         "chg",
         "quantity_ratio",
         "amount_level",
         "real_exchange",
         "disk_ratio",
         'real_disk_diff_amount_exchange',
         'max_real_main_inflow_multiple',
         'sum_main_inflow_disk',
         "main_inflow_multiple",
         'super_main_inflow_multiple',
         'disk_diff_amount',
         "disk_diff_amount_exchange",
         "exchange",
         "amount",
         "today_main_net_inflow",
         "today_main_net_inflow_ratio",
         "super_large_order_net_inflow",
         "super_large_order_net_inflow_ratio",
         "large_order_net_inflow",
         "large_order_net_inflow_ratio",
         "super_main_inflow_multiple",
         "up_speed",
         "up_speed_05",
         "now_price",
         "high",
         "low",
         "open",
         "yesterday_price",
         "volume",
         "total_mv",
         "flow_mv",
         "list_date",
         "wei_bi",
         "buy_1_num",
         "sell_1_num",
         "outer_disk",
         "inner_disk",
         "average_price",
         "classification",
         "str_now_date",
         "number"]


# 实时表移除数据
@async_fun
def remove_real_time_data(number, realtime_quotes_db_name):
    if number % 50 == 0:
        remove_query = {'number': {"$lte": number - 50}}
        mongodb_util.remove_data(remove_query, realtime_quotes_db_name)


def remove_real_time_all_data():
    remove_query = {}
    mongodb_util.remove_data(remove_query, db_name_constant.REAL_TIME_QUOTES_NOW)


# 保存实时表数据
def save_real_time_quotes(real_time_quotes, now_date, realtime_quotes_db_name, number):
    if 'first_sw_industry' in real_time_quotes.columns:
        real_time_quotes.drop(columns=['first_sw_industry'], inplace=True)
    if 'second_sw_industry' in real_time_quotes.columns:
        real_time_quotes.drop(columns=['second_sw_industry'], inplace=True)
    if 'third_sw_industry' in real_time_quotes.columns:
        real_time_quotes.drop(columns=['third_sw_industry'], inplace=True)
    real_time_quotes.symbol = real_time_quotes.symbol.astype(str)
    str_now_date = now_date.strftime('%Y-%m-%d %H:%M:%S:%f')
    real_time_quotes['_id'] = real_time_quotes['symbol'] + '-' + str_now_date

    try:

        real_time_quotes = real_time_quotes[order]
        real_time_quotes['sum_main_inflow_disk'] = round(real_time_quotes['sum_main_inflow_disk'], 2)
        mongodb_util.insert_mongo(real_time_quotes, realtime_quotes_db_name)
        # 移除现在的数据
        remove_real_time_data(number, realtime_quotes_db_name)
    except BaseException as e:
        logger.error('保存实时数据异常:{}', e)


# 保存历史表数据
def save_real_time_quotes_his(real_time_quotes, now_date, realtime_quotes_db_name, number_his):
    if 'first_sw_industry' in real_time_quotes.columns:
        real_time_quotes.drop(columns=['first_sw_industry'], inplace=True)
    if 'second_sw_industry' in real_time_quotes.columns:
        real_time_quotes.drop(columns=['second_sw_industry'], inplace=True)
    if 'third_sw_industry' in real_time_quotes.columns:
        real_time_quotes.drop(columns=['third_sw_industry'], inplace=True)
    real_time_quotes.symbol = real_time_quotes.symbol.astype(str)
    str_now_date = now_date.strftime('%Y-%m-%d %H:%M:%S:%f')
    real_time_quotes['_id'] = real_time_quotes['symbol'] + '-' + str_now_date

    try:
        real_time_quotes['number'] = number_his

        real_time_quotes = real_time_quotes[order]
        mongodb_util.insert_mongo(real_time_quotes, realtime_quotes_db_name)
    except Exception as e:
        logger.error('保存实时历史数据异常:{}', e)


def handle_init_real_time_quotes_data(real_time_quotes_now, str_now_date, number):
    #  exclude b symbol
    real_time_quotes_now = common_service_fun_api.exclude_b_symbol(real_time_quotes_now.copy())
    #  classification symbol
    real_time_quotes_now = common_service_fun_api.classify_symbol(real_time_quotes_now.copy())
    #  fix industry
    real_time_quotes_now = fix_industry_data(real_time_quotes_now.copy())
    #  calculate parameter
    real_time_quotes_now = data_init_api.calculate_parameter_factor(real_time_quotes_now.copy())

    real_time_quotes_now = real_time_quotes_now.loc[real_time_quotes_now['amount'] != 0]
    real_time_quotes_now['str_now_date'] = str_now_date
    real_time_quotes_now['number'] = number
    return real_time_quotes_now


# fix 错杀数据 有成交量的数据
def fix_industry_data(real_time_quotes_now):
    #  fix industry
    real_time_quotes_now_r = company_common_service_api.amendment_industry(real_time_quotes_now.copy())

    symbol_list = list(real_time_quotes_now_r['symbol'])

    na_real_now = real_time_quotes_now.loc[
        ~(real_time_quotes_now['symbol'].isin(symbol_list))]

    na_real_now = na_real_now.loc[na_real_now['amount'] != 0]

    real_time_quotes_now_result = pd.concat([real_time_quotes_now_r, na_real_now], axis=0)
    return real_time_quotes_now_result


def sync_realtime_quotes():
    # 移除昨日数据
    remove_real_time_all_data()

    now_date_init = datetime.datetime.now()
    str_day_init = now_date_init.strftime('%Y-%m-%d')
    realtime_quotes_db_name = db_name_constant.REAL_TIME_QUOTES_NOW + "_" + str_day_init
    number_his = common_service_fun_api.realtime_quotes_now_max_number(realtime_quotes_db_name, 'number')
    number_his = number_his + 1
    number = common_service_fun_api.realtime_quotes_now_max_number(
        db_name_constant.REAL_TIME_QUOTES_NOW + '_' + str_day_init, 'number')
    number = number + 1
    realtime_quotes_now_create_db_index_api.create_db_index(str_day_init)
    while True:
        now_date = datetime.datetime.now()

        str_now_date = now_date.strftime('%Y-%m-%d %H:%M:%S')
        if bool(date_util.is_trade_time(now_date)):
            try:
                real_time_quotes_now = east_money_stock_api.get_real_time_quotes_all_stocks()
                real_time_quotes_now = handle_init_real_time_quotes_data(real_time_quotes_now.copy(),
                                                                         str_now_date, number)
                save_real_time_quotes(real_time_quotes_now.copy(), now_date, db_name_constant.REAL_TIME_QUOTES_NOW,
                                      number)
                try:
                    auto_sell_service_api.auto_sell_stock(real_time_quotes_now.copy())
                except Exception as e:
                    logger.error("自动卖出执行异常:{}", e)
                # 集合竞价前同步
                if date_util.is_call_auction(str_now_date):
                    if number % 4 == 0:
                        save_real_time_quotes_his(real_time_quotes_now.copy(), now_date, realtime_quotes_db_name,
                                                  number_his)
                        number_his = number_his + 1
                # 开盘前一个小时同步
                elif date_util.is_begin_one_hour(now_date):
                    save_real_time_quotes_his(real_time_quotes_now.copy(), now_date, realtime_quotes_db_name,
                                              number_his)
                    number_his = number_his + 1
                # 下午同步次数
                elif date_util.is_afternoon_time(now_date):
                    if number % 3 == 0:
                        save_real_time_quotes_his(real_time_quotes_now.copy(), now_date, realtime_quotes_db_name,
                                                  number_his)
                        number_his = number_his + 1

                else:
                    # 10:30 到11:30
                    if number % 2 == 0:
                        save_real_time_quotes_his(real_time_quotes_now.copy(), now_date, realtime_quotes_db_name,
                                                  number_his)
                        number_his = number_his + 1

                logger.info("同步实时行情信息:{}", number)
                number = number + 1

            except Exception as e:
                number_his = number_his + 1
                number = number + 1
                logger.error("获取实时行情信息:{}", e)
        elif bool(date_util.is_no_trade_time(now_date)):

            break
        else:
            time.sleep(1)


if __name__ == '__main__':
    sync_realtime_quotes()



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)
import pandas as pd
from loguru import logger
import mns_common.component.common_service_fun_api as common_service_fun_api
import mns_common.component.trade_date.trade_date_common_service_api as trade_date_common_service_api
import mns_common.api.em.east_money_stock_api as east_money_stock_api
import mns_common.utils.date_handle_util as date_handle_util
import mns_common.component.company.company_common_service_api as company_common_service_api
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.utils.data_frame_util as data_frame_util
import mns_common.component.zt.zt_common_service_api as zt_common_service_api
import mns_common.constant.db_name_constant as db_name_constant
from datetime import datetime
import mns_common.component.k_line.common.k_line_common_service_api as k_line_common_service_api
import mns_common.component.concept.ths_concept_common_service_api as ths_concept_common_service_api

mongodb_util = MongodbUtil('27017')


# 保存高涨股票列表


def sync_stock_high_chg_pool_list(str_day, symbol_list):
    zt_pool_stocks = get_zt_pool(str_day)
    k_line_high_chg_stocks = k_line_high_chg(str_day, symbol_list)
    if data_frame_util.is_empty(zt_pool_stocks):
        return None
    # 涨停池中的股票
    zt_pool_stocks_symbol_list = list(zt_pool_stocks['symbol'])
    zt_pool_stocks = zt_pool_stocks[['symbol',
                                     'name',
                                     "chg",
                                     'now_price',
                                     "first_closure_time",
                                     "last_closure_time",
                                     "connected_boards_numbers",
                                     "zt_reason",
                                     "closure_funds",
                                     "frying_plates_numbers",
                                     "statistics",
                                     "ths_concept_name",
                                     "ths_concept_code",
                                     "ths_concept_sync_day",
                                     "amount",
                                     "high",
                                     "low",
                                     "open",

                                     "exchange",
                                     "flow_mv",
                                     "total_mv",
                                     "classification",
                                     "flow_mv_sp",
                                     "total_mv_sp",
                                     "flow_mv_level",
                                     "amount_level",
                                     "str_day"
                                     ]]

    all_company_info_df = company_common_service_api.get_company_info_industry_list_date()

    zt_pool_company_df = all_company_info_df[[
        '_id',
        'industry',
        'company_type',
        'list_date'
    ]]

    zt_pool_company_df = zt_pool_company_df.loc[all_company_info_df['_id'].isin(zt_pool_stocks_symbol_list)]
    zt_pool_company_df = zt_pool_company_df.set_index(['_id'], drop=True)
    zt_pool_stocks = zt_pool_stocks.set_index(['symbol'], drop=False)
    zt_pool_stocks = pd.merge(zt_pool_stocks, zt_pool_company_df, how='outer',
                              left_index=True, right_index=True)

    # 高涨幅股票未涨停 wei_bi !=100
    high_chg_no_zt_pool = k_line_high_chg_stocks.loc[
        ~(k_line_high_chg_stocks['symbol'].isin(zt_pool_stocks_symbol_list))]

    high_chg_no_zt_pool = high_chg_no_zt_pool.rename(columns={
        "close": "now_price"})

    high_chg_no_zt_pool = high_chg_no_zt_pool[[
        'symbol',
        'name',
        'chg',
        'now_price',
        "amount",
        "high",
        "low",
        "open",
        "exchange",
        "classification",
        "flow_mv",
        "flow_mv_sp",
        "amount_level"
    ]]
    high_chg_no_zt_pool['first_closure_time'] = '无'
    high_chg_no_zt_pool['last_closure_time'] = '无'
    high_chg_no_zt_pool['connected_boards_numbers'] = 1
    high_chg_no_zt_pool['zt_reason'] = '无'
    high_chg_no_zt_pool['closure_funds'] = 0
    high_chg_no_zt_pool['frying_plates_numbers'] = 0
    high_chg_no_zt_pool['statistics'] = '1/1'
    # 暂无
    high_chg_no_zt_pool['total_mv'] = 0
    high_chg_no_zt_pool['total_mv_sp'] = 0
    high_chg_no_zt_pool['flow_mv_level'] = 0

    high_chg_no_zt_pool['str_day'] = str_day

    high_chg_no_zt_company_df = all_company_info_df[[
        '_id',
        'industry',
        'company_type',
        'list_date',
        'ths_concept_name',
        'ths_concept_code',
        'ths_concept_sync_day'
    ]]

    high_chg_no_zt_company_df = high_chg_no_zt_company_df.loc[
        all_company_info_df['_id'].isin(list(high_chg_no_zt_pool['symbol']))]

    high_chg_no_zt_company_df = high_chg_no_zt_company_df.set_index(['_id'], drop=True)
    high_chg_no_zt_pool = high_chg_no_zt_pool.set_index(['symbol'], drop=False)

    high_chg_no_zt_pool = pd.merge(high_chg_no_zt_pool, high_chg_no_zt_company_df, how='outer',
                                   left_index=True, right_index=True)

    high_chg_pool = pd.concat([zt_pool_stocks, high_chg_no_zt_pool])

    now_date = datetime.now()
    now_day = now_date.strftime('%Y-%m-%d')

    real_time_quotes_now_init = east_money_stock_api.get_real_time_quotes_all_stocks()

    last_trade_zt_pool = zt_common_service_api.get_last_trade_day_zt(str_day)

    zt_symbol_connected_boards_numbers_list = last_trade_zt_pool.loc[
        last_trade_zt_pool['symbol'].isin(high_chg_pool['symbol'])]

    # 所有重置为1
    high_chg_pool['connected_boards_numbers'] = 1

    if zt_symbol_connected_boards_numbers_list is not None and zt_symbol_connected_boards_numbers_list.shape[0] != 0:
        for yesterday_zt in zt_symbol_connected_boards_numbers_list.itertuples():
            high_chg_pool.loc[
                high_chg_pool["symbol"] == yesterday_zt.symbol, ['connected_boards_numbers']] \
                = 1 + yesterday_zt.connected_boards_numbers

    for stock_one in high_chg_pool.itertuples():
        try:

            symbol = stock_one.symbol
            stock_one_df = high_chg_pool.loc[high_chg_pool['symbol'] == symbol]

            classification = common_service_fun_api.classify_symbol_one(symbol)
            stock_one_df['classification'] = classification

            if classification == "X" and stock_one.chg > 31:
                continue

            list_date = stock_one.list_date
            if list_date is None or pd.isna(list_date):
                list_date = '1989-07-29'
                diff_days = 10000
            else:
                list_date = str(list_date)
                list_date = list_date.replace(".0", "")
                list_date = date_handle_util.lash_date(list_date)

                list_date_time = date_handle_util.str_to_date(list_date, "%Y-%m-%d")
                str_now_day_time = date_handle_util.str_to_date(str_day, "%Y-%m-%d")

                diff_days = date_handle_util.days_diff(str_now_day_time, list_date_time)
                # 上市新股
                if diff_days == 0:
                    continue

            stock_one_df['list_day'] = list_date
            # 上市天数
            stock_one_df['diff_days'] = diff_days
            # 交易天数
            deal_days = k_line_common_service_api.get_deal_days(str_day, symbol)
            stock_one_df['deal_days'] = deal_days

            last_trade_day = trade_date_common_service_api.get_last_trade_day(str_day)

            # 上个交易日是否是高涨幅
            last_day_high_chg = mongodb_util.exist_data_query(db_name_constant.STOCK_QFQ_DAILY,
                                                              query={"symbol": symbol, "date": last_trade_day,
                                                                     "chg": {'$gte': common_service_fun_api.ZT_CHG}})
            stock_one_df['last_day_high_chg'] = last_day_high_chg

            open_price = stock_one.open
            high = stock_one.high
            close = stock_one.now_price
            yi_zhi_ban = False
            if open_price == high and open_price == close:
                yi_zhi_ban = True

            stock_one_df['yi_zhi_ban'] = yi_zhi_ban
            stock_one_df['today_main_net_inflow'] = 0

            if now_day == str_day:
                real_time_quotes_now_one = real_time_quotes_now_init.loc[
                    real_time_quotes_now_init['symbol'] == symbol]
                stock_one_df['total_mv'] = list(real_time_quotes_now_one['total_mv'])[0]
                stock_one_df['today_main_net_inflow'] = list(real_time_quotes_now_one['today_main_net_inflow'])[0]

            stock_one_df.loc[:, ['flow_mv_level']] \
                = ((stock_one_df["flow_mv"] / common_service_fun_api.HUNDRED_MILLION) // 10) + 1
            stock_one_df['total_mv_sp'] = round((stock_one_df['total_mv'] / common_service_fun_api.HUNDRED_MILLION), 2)
            stock_one_df["_id"] = stock_one_df['symbol'] + "_" + str_day
            stock_one_df['remark'] = ''
            symbol_last_concept_df = get_symbol_last_concept(symbol, str_day)
            if data_frame_util.is_not_empty(symbol_last_concept_df):
                ths_concept_name = list(symbol_last_concept_df['concept_name'])[0]
                ths_concept_sync_day = list(symbol_last_concept_df['str_day'])[0]
                ths_concept_code = list(symbol_last_concept_df['concept_code'])[0]
                stock_one_df['ths_concept_name'] = ths_concept_name
                stock_one_df['ths_concept_code'] = ths_concept_code
                stock_one_df['ths_concept_sync_day'] = ths_concept_sync_day

            stock_one_df['ths_concept_name'].fillna('退市', inplace=True)
            stock_one_df['ths_concept_code'].fillna(0, inplace=True)
            stock_one_df['ths_concept_sync_day'].fillna('1989-07-29', inplace=True)
            stock_one_df['industry'].fillna('退市', inplace=True)
            stock_one_df['company_type'].fillna('', inplace=True)
            stock_one_df['list_date'].fillna(19890729, inplace=True)
            stock_one_df['chg'] = round(stock_one_df['chg'], 2)
            stock_one_df['exchange'] = round(stock_one_df['exchange'], 2)
            stock_one_df['today_main_net_inflow'] = round(
                stock_one_df['today_main_net_inflow'] / common_service_fun_api.TEN_THOUSAND, 2)
            stock_one_df['flag'] = ''
            id_key = symbol + "_" + str_day
            if mongodb_util.exist_data_query(db_name_constant.STOCK_HIGH_CHG_POOL, query={"_id": id_key}):
                continue

            mongodb_util.save_mongo(stock_one_df, db_name_constant.STOCK_HIGH_CHG_POOL)
            logger.info("更新高涨幅数据成功{},{}", stock_one.symbol, str_day)
        except Exception as e:
            logger.error("更新高涨幅数据异常:{},{},{}", stock_one.symbol, str_day, e)
            continue

    return high_chg_no_zt_pool


# 通过k线获取高涨幅股票
def k_line_high_chg(str_day, symbol_list):
    if symbol_list is None:
        query = {"date": date_handle_util.no_slash_date(str_day), "chg": {'$gte': common_service_fun_api.ZT_CHG}}
    else:
        query = {"date": date_handle_util.no_slash_date(str_day), "symbol": {'$in': symbol_list}}
    # 今日高涨幅的list
    return mongodb_util.find_query_data(db_name_constant.STOCK_QFQ_DAILY, query)


# 获取当日涨停池中股票
def get_zt_pool(str_day):
    # 今日涨停股
    query_zt = {'str_day': str_day}
    zt_pool = mongodb_util.find_query_data(db_name_constant.STOCK_ZT_POOL, query_zt)
    if data_frame_util.is_empty(zt_pool):
        return pd.DataFrame()
    if 'zt_reason' not in zt_pool.columns:
        zt_pool['zt_reason'] = '无'
    if 'ths_concept_name' not in zt_pool.columns:
        zt_pool['ths_concept_name'] = '无'
    if 'ths_concept_code' not in zt_pool.columns:
        zt_pool['ths_concept_code'] = 0
    if 'ths_concept_sync_day' not in zt_pool.columns:
        zt_pool['ths_concept_sync_day'] = 0
    if 'high' not in zt_pool.columns:
        zt_pool['high'] = 0
    if 'low' not in zt_pool.columns:
        zt_pool['low'] = 0
    if 'open' not in zt_pool.columns:
        zt_pool['open'] = 0
    zt_pool['amount_level'] = round(zt_pool['amount'] / common_service_fun_api.HUNDRED_MILLION, 2)
    return zt_pool


def get_symbol_last_concept(symbol, str_day):
    ths_effective_concept_df = ths_concept_common_service_api.get_all_ths_effective_concept()
    ths_effective_concept_code = list(ths_effective_concept_df['symbol'])
    query = {"symbol": symbol, 'str_day': {"$lte": str_day}, 'concept_code': {"$in": ths_effective_concept_code}}
    return mongodb_util.descend_query(query, db_name_constant.THS_STOCK_CONCEPT_DETAIL, 'str_day', 1)






import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)

from loguru import logger
import mns_common.component.common_service_fun_api as common_service_fun_api
import mns_common.utils.date_handle_util as date_handle_util
import mns_common.component.company.company_common_service_api as company_common_service_api
import mns_common.component.data.data_init_api as data_init_api
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.utils.db_util as db_util
import mns_common.constant.db_name_constant as db_name_constant

mongodb_util = MongodbUtil('27017')

# 保存高涨股票当天实时行情数据


choose_field = ["_id",
                "symbol",
                "name",
                "industry",
                "now_price",
                "chg",
                "quantity_ratio",
                "amount_level",
                "disk_ratio",
                "real_disk_diff_amount_exchange",
                'max_real_main_inflow_multiple',
                'sum_main_inflow_disk',
                "real_main_inflow_multiple",
                "real_super_main_inflow_multiple",
                "super_main_inflow_multiple",
                "main_inflow_multiple",
                "disk_diff_amount_exchange",
                "large_inflow_multiple",
                "today_main_net_inflow",
                "today_main_net_inflow_ratio",
                "super_large_order_net_inflow",
                "super_large_order_net_inflow_ratio",
                "large_order_net_inflow",
                "large_order_net_inflow_ratio",
                "reference_main_inflow",
                "disk_diff_amount",
                "mv_circulation_ratio",
                "real_exchange",
                "exchange",
                'real_exchange',
                "total_mv",
                "flow_mv",
                "volume",
                "high",
                "low",
                "open",
                "yesterday_price",
                "amount",
                "total_mv_sp",
                "flow_mv_sp",
                "outer_disk",
                "inner_disk",
                "classification",
                "number",
                "str_day",
                "str_now_date"
                ]


# 同步高涨幅股票实时行情数据
def sync_high_chg_real_time_quotes(str_day):
    mongo = db_util.get_db(str_day)

    realtime_quotes_db_name = 'realtime_quotes_now_' + str_day
    high_chg_list = get_high_chg_symbol(str_day)
    if high_chg_list is None or len(high_chg_list) == 0:
        return

    for symbol in high_chg_list:
        try:
            query_all = {"symbol": symbol}
            real_time_quotes_now_high_chg_all = mongo.find_query_data(realtime_quotes_db_name, query_all)
            if real_time_quotes_now_high_chg_all.shape[0] == 0:
                return
            real_time_quotes_now_high_chg_all = company_common_service_api.amendment_industry_exist_na(
                real_time_quotes_now_high_chg_all,
                high_chg_list)
            real_time_quotes_now_high_chg_all.dropna(subset=['symbol'], axis=0,
                                                     inplace=True)
            real_time_quotes_now_high_chg_all = data_init_api.calculate_parameter_factor(
                real_time_quotes_now_high_chg_all)

            real_time_quotes_now_high_chg_all['amount_level'] = round(
                (real_time_quotes_now_high_chg_all['amount'] / common_service_fun_api.HUNDRED_MILLION), 2) * 10
            real_time_quotes_now_high_chg_all['flow_mv_sp'] = round(
                (real_time_quotes_now_high_chg_all['flow_mv'] / common_service_fun_api.HUNDRED_MILLION), 2)
            real_time_quotes_now_high_chg_all['total_mv_sp'] = round(
                (real_time_quotes_now_high_chg_all['total_mv'] / common_service_fun_api.HUNDRED_MILLION), 2)

            save_realtime_quotes_now_zt_data(real_time_quotes_now_high_chg_all, str_day, symbol)
            logger.info("同步高涨幅股票实时行情数据信息:{},{}", str_day, symbol)
        except BaseException as e:
            logger.error("同步高涨幅股票实时行情数据发生异常:{}:{},{}", str_day, e, symbol)


# 获取 str_day 高涨幅列表 k线和涨停池中
def get_high_chg_symbol(str_day):
    query = {"date": date_handle_util.no_slash_date(str_day), "chg": {'$gte': common_service_fun_api.ZT_CHG}}
    # 今日高涨幅的list
    real_time_quotes_now_high_chg = mongodb_util.find_query_data(db_name_constant.STOCK_QFQ_DAILY, query)
    if real_time_quotes_now_high_chg.shape[0] == 0:
        return None
    high_chg_list = list(real_time_quotes_now_high_chg['symbol'])
    # 今日涨停股
    query_zt = {'str_day': str_day}
    zt_pool = mongodb_util.find_query_data(db_name_constant.STOCK_ZT_POOL, query_zt)
    if zt_pool.shape[0] > 0:
        zt_pool_list = list(zt_pool['symbol'])
        high_chg_list.extend(zt_pool_list)
    high_chg_list = list(set(high_chg_list))
    return high_chg_list


# 保存high chg 股票实时行情数据
def save_realtime_quotes_now_zt_data(realtime_quotes_now_zt, str_day, symbol):
    realtime_quotes_now_zt = common_service_fun_api.classify_symbol(realtime_quotes_now_zt.copy())
    # create_index()
    if 'wei_bi' in realtime_quotes_now_zt.columns and bool(1 - ("wei_bi" in choose_field)):
        choose_field.append("wei_bi")
    if 'up_speed' in realtime_quotes_now_zt.columns and bool(1 - ("up_speed" in choose_field)):
        choose_field.append("up_speed")
    if 'list_date' in realtime_quotes_now_zt.columns and bool(1 - ("list_date" in choose_field)):
        choose_field.append("list_date")
    realtime_quotes_now_zt.loc[:, 'str_day'] = str_day
    realtime_quotes_now_zt = realtime_quotes_now_zt[choose_field]
    remove_query = {"symbol": symbol, "str_day": str_day}
    result = mongodb_util.remove_data(remove_query, db_name_constant.ZT_STOCK_REAL_TIME_QUOTES).acknowledged
    if result:
        mongodb_util.insert_mongo(realtime_quotes_now_zt, db_name_constant.ZT_STOCK_REAL_TIME_QUOTES)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)

# 每月最大交易天数
MAX_TRADE_DAYS_PER_MONTH = 23
# 每周最大交易天数
MAX_TRADE_DAYS_PER_MONTH = 5


def handle_month_week_line(k_line_info, stock_qfq_daily, deal_days):
    if 1 < deal_days < MAX_TRADE_DAYS_PER_MONTH:
        month_01 = round(sum(stock_qfq_daily['chg']), 2)
        k_line_info['sum_month'] = month_01
        k_line_info['month_num'] = 1
        k_line_info['month01'] = month_01
    elif (deal_days >= MAX_TRADE_DAYS_PER_MONTH) \
            and (deal_days < MAX_TRADE_DAYS_PER_MONTH * 2):
        stock_qfq_daily_month_01 = stock_qfq_daily.iloc[0:MAX_TRADE_DAYS_PER_MONTH]
        month_01 = round(sum(stock_qfq_daily_month_01['chg']), 2)
        stock_qfq_daily_month_02 = stock_qfq_daily.iloc[MAX_TRADE_DAYS_PER_MONTH + 1, deal_days - 1]
        month_02 = round(sum(stock_qfq_daily_month_02['chg']), 2)
        k_line_info['sum_month'] = round(month_01 + month_02, 2)
        k_line_info['month_num'] = 2
        k_line_info['month01'] = month_01
        k_line_info['month_02'] = month_02
    elif deal_days >= MAX_TRADE_DAYS_PER_MONTH * 2:
        stock_qfq_daily_month_01 = stock_qfq_daily.iloc[0:MAX_TRADE_DAYS_PER_MONTH]
        month_01 = round(sum(stock_qfq_daily_month_01['chg']), 2)
        stock_qfq_daily_month_02 = stock_qfq_daily.iloc[MAX_TRADE_DAYS_PER_MONTH + 1, MAX_TRADE_DAYS_PER_MONTH * 2]
        month_02 = round(sum(stock_qfq_daily_month_02['chg']), 2)

        stock_qfq_daily_week_sum = stock_qfq_daily.iloc[MAX_TRADE_DAYS_PER_MONTH * 2 + 1, deal_days - 1]

        week_sum = round(sum(stock_qfq_daily_week_sum['chg']), 2)

        k_line_info['sum_month'] = round(month_01 + month_02, 2)
        k_line_info['month_num'] = 2
        k_line_info['month01'] = month_01
        k_line_info['month_02'] = month_02

        k_line_info['week_num'] = week_sum
    return k_line_info



import sys
import os
from datetime import datetime
import mns_common.constant.db_name_constant as db_name_constant
import mns_common.component.self_choose.black_list_service_api as black_list_service_api
import mns_common.component.common_service_fun_api as common_service_fun_api
from mns_common.constant.black_list_classify_enum import BlackClassify

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)

# 利润为负的时候最小营业收入 主板 3.2亿
MIN_INCOME_MAIN = 320000000
# 利润为负的时候最小营业收入 科创 创业 1.2亿
MIN_INCOME_SUB = 120000000


# 营收利润check

def profit_income_check(new_report_df, period_time, report_type):
    new_report_one_df = new_report_df.loc[new_report_df['REPORT_DATE'] == period_time]
    symbol = list(new_report_one_df['SECURITY_CODE'])[0]
    name = list(new_report_one_df['SECURITY_NAME_ABBR'])[0]
    now_date = datetime.now()
    str_day = now_date.strftime('%Y-%m-%d')
    str_now_date = now_date.strftime('%Y-%m-%d %H:%M:%S')
    notice_date = list(new_report_one_df['NOTICE_DATE'])[0]
    if report_type == db_name_constant.EM_STOCK_PROFIT:
        # 利润总额  净利润 扣除非经常性损益后的净利润  三者最小为负
        # 利润总额
        total_profit = list(new_report_one_df['TOTAL_PROFIT'])[0]
        #  净利润
        net_profit = list(new_report_one_df['NETPROFIT'])[0]
        # 营业利润
        operate_profit = list(new_report_one_df['OPERATE_PROFIT'])[0]
        # 持续经营净利润
        continued_profit = list(new_report_one_df['CONTINUED_NETPROFIT'])[0]
        # 归属于母公司股东的净利润
        parent_profit = list(new_report_one_df['PARENT_NETPROFIT'])[0]
        # 扣除非经常性损益后的净利润
        deduct_parent_profit = list(new_report_one_df['DEDUCT_PARENT_NETPROFIT'])[0]
        # 营业总收入
        total_operate_income = list(new_report_one_df['TOTAL_OPERATE_INCOME'])[0]
        if total_operate_income == 0:
            #  营业收入
            total_operate_income = list(new_report_one_df['OPERATE_INCOME'])[0]

            # 最小利润收入
        min_profit = min(total_profit, net_profit, operate_profit,
                         continued_profit, parent_profit, deduct_parent_profit)
        if min_profit < 0:

            classification = common_service_fun_api.classify_symbol_one(symbol)
            if ((classification in ['S', 'H'] and total_operate_income < MIN_INCOME_MAIN)
                    | (classification in ['K', 'C'] and total_operate_income < MIN_INCOME_SUB)):
                id_key = symbol + "_" + period_time + "_" + BlackClassify.FINANCIAL_PROBLEM_PROFIT.level_code
                min_profit = round(min_profit / common_service_fun_api.TEN_THOUSAND, 1)
                total_operate_income = round(total_operate_income / common_service_fun_api.HUNDRED_MILLION, 1)

                black_list_service_api.save_black_stock(id_key,
                                                        symbol,
                                                        name,
                                                        str_day,
                                                        notice_date,
                                                        '年报:利润:' + '[' + str(min_profit) + '万]' + '收入:' + str(
                                                            total_operate_income) + '[' + '亿元]--' + '触发退市风险',
                                                        '年报:利润:' + '[' + str(min_profit) + '万]' + '收入:' + str(
                                                            total_operate_income) + '[' + '亿元]--' + '触发退市风险',
                                                        '',
                                                        BlackClassify.FINANCIAL_PROBLEM_PROFIT.up_level_code,
                                                        BlackClassify.FINANCIAL_PROBLEM_PROFIT.up_level_name,
                                                        BlackClassify.FINANCIAL_PROBLEM_PROFIT.level_code,
                                                        BlackClassify.FINANCIAL_PROBLEM_PROFIT.level_name)
